
:mod:`anyconfig_configobj_backend.configobj`
----------------------------------------------

.. automodule:: anyconfig_configobj_backend.configobj
   :members:
   :special-members:
   :private-members:
   :undoc-members:
   :show-inheritance:

.. vim:sw=2:ts=2:et:
